#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub OPEN  {}    # XXX Hackery in case the user redirects
sub CLOSE {}    # XXX STDERR/STDOUT.  This is not the behavior we want.

sub READ {}
sub READLINE {}
sub GETC {}
sub BINMODE {}

my $Original_File = 'root/etc/e-smith/web/functions/groups';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 40 root/etc/e-smith/web/functions/groups

use esmith::FormMagick::Tester;
use esmith::TestUtils;
use esmith::AccountsDB;
my $panel = 'groups';
my $panel_path = "/etc/e-smith/web/functions/".$panel;
my $ua = esmith::FormMagick::Tester->new();


is  (mode($panel_path), '4750',              "Check permissions on script");
ok  ($ua->get_panel($panel),            "ABOUT TO RUN L10N TESTS");
is  ($ua->{status}, 200,                "200 OK");
like($ua->{content}, qr/FORM_TITLE/,    "Saw untranslated form title");
ok  ($ua->set_language("en"),           "Set language to English");
ok  ($ua->get_panel($panel),            "Get panel");

is  ($ua->{status}, 200,                "200 OK");

like($ua->{content}, qr/Create, remove, or change/, "Saw translated form title");

# Testing changes

ok  ($ua->get_panel($panel),            "Testing panel retrieval");
can_ok($ua, "field");

# Destructive testing:

ok ($ua->follow('Click here to create a user group'), "Followed link to create group");
is  ($ua->{status}, 200,                "200 OK" );
can_ok($ua, "field");
ok($ua->field('groupName' => 'aaaaaeve') , "Set GroupName");
ok($ua->field('groupDesc' => 'sample'), "Set GroupDesc");

if (destruction_ok()) {

ok ($ua->click('Create'), "Clicked create");
is  ($ua->{status}, 200,                "200 OK" );
like ($ua->{content}, qr/created user group/, "Saw create success message");
ok  ($ua->get_panel($panel),            "Get panel");
like ($ua->{content}, qr/aaaaaeve/, "Saw newly created everygroup link");
ok ($ua->follow('Modify'),  "modifying aaaaaeve");
is  ($ua->{status}, 200,                "200 OK ");
ok ($ua->field('groupDesc' => 'Everyone') , "Set group desc to 'Everyone'");

#putting this in a test fails. why?
$ua->field('groupMembers' => 'admin');
ok ($ua->click('Modify'));
is  ($ua->{status}, 200,                "200 OK");
like ($ua->{content}, qr/Successfully/, "Saw modification success message");
ok (my $acct = esmith::AccountsDB->open());
ok (my $everg = $acct->get('aaaaaeve'), "Got an aaaaaeveg out of the db");
ok ($everg->prop('Members') eq 'admin', "aaaaaeve has admin as its member");

ok  ($ua->get_panel($panel),            "Get panel");
like ($ua->{content}, qr/aaaaaeve/, "Saw modified everygroup link");
ok ($ua->follow('Remove'),  "removing aaaaaeve");
is  ($ua->{status}, 200,                "200 OK");
ok ($ua->click('Remove'));
is  ($ua->{status}, 200,                "200 OK");
like ($ua->{content}, qr/Successfully/, "Saw removal success message");
ok  ($ua->get_panel($panel),            "Get panel");
unlike ($ua->{content}, qr/aaaaaeve/, "Saw no everygroup");
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

