#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub OPEN  {}    # XXX Hackery in case the user redirects
sub CLOSE {}    # XXX STDERR/STDOUT.  This is not the behavior we want.

sub READ {}
sub READLINE {}
sub GETC {}
sub BINMODE {}

my $Original_File = 'root/etc/e-smith/web/panels/manager/cgi-bin/useraccounts';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 61 root/etc/e-smith/web/panels/manager/cgi-bin/useraccounts

use esmith::FormMagick::Tester;
use esmith::TestUtils;
use esmith::ConfigDB;
use esmith::AccountsDB;

my $panel = $Original_File;
my $ua = esmith::FormMagick::Tester->new();

my $c = esmith::ConfigDB->open();
my $a = esmith::AccountsDB->open();

is  (mode($panel), '4755',              "Check permissions on script");
ok  ($ua->get_panel($panel),            "ABOUT TO RUN L10N TESTS");
is  ($ua->{status}, 200,                "200 OK");
like($ua->{content}, qr/FORM_TITLE/,    "Saw untranslated form title");
ok  ($ua->set_language("en-us"),        "Set language to U.S. English");
ok  ($ua->get_panel($panel),            "Get panel");
is  ($ua->{status}, 200,                "200 OK");
like($ua->{content}, qr/User accounts/, "Saw translated form title");


#
# Testing creating users
#

ok  ($ua->get_panel($panel),            "ABOUT TO TEST CREATING USER");
ok  ($ua->follow("Click here"),         "Follow 'create user' link");
is  ($ua->{status}, 200,                "200 OK");
like($ua->{content}, qr/Account name/,  "Saw form fields");

#
# Check that address details are picked up from LDAP
#

my $ldap_record = $c->get('ldap');
my $city = $ldap_record->prop('DefaultCity');

like($ua->{content}, qr/$city/, "Pick up address from LDAP");

#
# Creating a new user
#

my $new_username = new_random_username();

can_ok($ua, "field");
ok  ($ua->{form}->find_input('acctName'), 
                                        "Find acctName field to fill in");
$ua->field("acctName" => $new_username);
ok  ($ua->click("Save"),                "Click Save");
is  ($ua->{status}, 200,                "200 OK");
like($ua->{content}, qr/must not be left blank/, "Saw validation messages");

$ua->field("FirstName" => "Fred");
$ua->field("LastName"  => "Foonly");

ok  ($ua->click("Save"),                "Click Save");
is  ($ua->{status}, 200,                "200 OK");

#
# Testing modify user
#

ok  ($ua->get_panel($panel),            "ABOUT TO TEST MODIFYING A USER");
is  ($ua->{status}, 200,                "200 OK");
ok  ($ua->follow('Modify'),             "Follow modify link");
is  ($ua->{status}, 200,                "200 OK");
like($ua->{content}, qr/value="Save"/,  "Saw 'Save' on the button");

#
# Testing removal of a user
#

ok  ($ua->get_panel($panel),            "ABOUT TO TEST USER REMOVAL");
is  ($ua->{status}, 200,                "200 OK");
ok  ($ua->follow('Remove'),             "Follow remove link");
is  ($ua->{status}, 200,                "200 OK");
like($ua->{content}, qr/Remove/,        "Saw 'Remove'");
like($ua->{content}, qr/value="Remove"/, "Saw 'Remove' on the button");

#
# Testing password reset
#

ok  ($ua->get_panel($panel),            "ABOUT TO TEST PASSWORD RESET");
is  ($ua->{status}, 200,                "200 OK");
ok  ($ua->follow('Reset password'),     "Follow reset password link");
like($ua->{content}, qr/Reset password/,"Saw 'Reset password'");

SKIP:
{
    skip 3, "Unsafe!" unless destruction_ok();
    $ua->field(password1 => "test");
    $ua->field(password2 => "test");
    ok($ua->click('Save'), "Set password to 'test', click Save");
    is($ua->{status}, 200, "200 OK");
    like($ua->{content}, qr/Click here/, "Returned to first page");
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

